//! Traits for checking layout compatibility and enforcing layout requirements.

pub mod bits_union;
pub mod typecheck;
pub mod valid_layout;
